"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ethers_1 = require("ethers");
class Utils {
    async fromChainId(chainId) {
        const network = {
            1: "mainnet",
            4: "rinkeby",
            3: "ropsten",
            42: "Kovan",
            420: "goerli",
            77: "sokol",
            122: "fuse",
            56: "bsc",
            97: "bsctest",
            250: "fantom",
            4002: "fantomtest",
            1287: "moonbase",
            1285: "moonriver",
            1284: "Moonbeam",
            137: "matic",
            80001: "mumbai",
            43114: "avalanche",
            43113: "fuji",
            10: "optimism",
            69: "optimism-kovan",
            42161: "arbitrum",
            421611: "arbitrum-rinkeby",
            42220: "celo",
            44787: "alfajores",
            1313161554: "aurora",
            1313161556: "auroratest",
        };
        return network[chainId];
    }
    getAbiInterfaceParams(AbiInterfaceParams) {
        const { abiInterface, name, type } = AbiInterfaceParams;
        const eventParams = {
            functionGet: "getEvent",
            consult: "events",
            signatures: "eventSignature",
        };
        const functionParams = {
            functionGet: "getEvent",
            consult: "functions",
            signatures: "functionSignature",
        };
        let returnParams = {
            name,
            signature: {},
        };
        const { functionGet, consult, signatures } = type === "event" ? eventParams : functionParams;
        returnParams.inputs = abiInterface[functionGet](name).inputs.map(({ name, type }) => {
            return { name, type };
        });
        returnParams.signature[signatures] = Object.keys(abiInterface[consult]).find((e) => e.split("(")[0] === name);
        returnParams.fragment = returnParams.signature[signatures];
        return returnParams;
    }
    AbiJsonString(abiInterface) {
        return abiInterface.format(ethers_1.utils.FormatTypes.json);
    }
}
exports.default = Utils;
//# sourceMappingURL=index.js.map